package com.chinaitop.depot.system.controller;

import com.chinaitop.depot.system.model.RoleInfo;
import com.chinaitop.depot.system.model.RoleInfoExample;
import com.chinaitop.depot.system.model.RoleInfoExample.Criteria;
import com.chinaitop.depot.system.model.RoleInfoVo;
import com.chinaitop.depot.system.service.RoleButtonService;
import com.chinaitop.depot.system.service.RoleFuncService;
import com.chinaitop.depot.system.service.RoleInfoService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value="/roleInfo")
public class RoleInfoController {
	
	@Resource
	private RoleInfoService roleInfoService;
	
	@Resource
	private RoleFuncService roleFuncService;
	
	@Resource
	private RoleButtonService roleButtonService;
	
	/**
	 * 查找角色信息
	 * @param pageNum	页码
	 * @param pageSize	每页条数
	 * @return
	 */
	@RequestMapping(value="/getRole")
	public PageInfo<RoleInfo> getRoleInfo(Integer pageNum, Integer pageSize, Integer parentId, String roleName) {
		RoleInfoExample example = new RoleInfoExample();
		Criteria criteria = example.createCriteria();
		if (parentId != null) {
			criteria.andParentIdEqualTo(parentId);
		}
		if (StringUtils.isNotBlank(roleName)) {
			criteria.andRoleNameLike("%" + roleName + "%");
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<RoleInfo> list = roleInfoService.queryByExample(example);	
		PageInfo<RoleInfo> pageInfo = new PageInfo<RoleInfo>(list);
		return pageInfo;
	}

	/**
	 * 根据编号查找角色信息
	 * @param roleId	角色编号
	 * @return	RoleInfo 角色信息
	 */
	@RequestMapping(value="/edit")
	public RoleInfo edit(Integer roleId) {
		RoleInfo roleInfo = new RoleInfo();
		if (roleId != null) {
			roleInfo = roleInfoService.findById(roleId);
		}
		return roleInfo;
	}

	/**
	 * 保存角色信息
	 * @param roleInfoJson	角色信息json字符串
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/save")
	public Map<String, Object> save(HttpServletRequest request, String roleInfoJson)
			throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		RoleInfo roleInfo = (RoleInfo)mapper.readValue(roleInfoJson, RoleInfo.class);
		Integer orgId = (Integer)request.getSession().getAttribute("orgId");
		roleInfo.setOrgId(orgId);
		if (roleInfo.getRoleId() == null) {
			roleInfoService.add(roleInfo);
		} else {
			roleInfoService.update(roleInfo);
		}
		modelMap.put("status", "success");
		return modelMap;
	}
	
	/**
	 * 根据编号删除角色
	 * @param roleId	角色编号
	 * @return
	 */
	@RequestMapping(value="/remove")
	public Map<String, Object> remove(Integer roleId) {
		Map<String, Object> modelMap = new HashMap<>();
		if (roleId != null) {
			roleInfoService.remove(roleId);
			roleFuncService.remove(roleId);
			roleButtonService.remove(roleId);
		}
		modelMap.put("status", "success");
		return modelMap;
	}
	
	@RequestMapping("/getRoleTree")
    public Map<String, Object> getRoleTree(HttpServletRequest request) {
		RoleInfoExample example = new RoleInfoExample();
		List<RoleInfo> list = roleInfoService.queryByExample(example);	
		Map<String, Object> modelMap = new HashMap<>();
		List<RoleInfoVo> voList = new ArrayList<RoleInfoVo>();
		Map<Integer, String> roleNameObj = new HashMap<Integer, String>();
		for (RoleInfo roleInfo : list) {
			RoleInfoVo roleInfoVo = new RoleInfoVo();
			roleInfoVo.setId(roleInfo.getRoleId());
			roleInfoVo.setName(roleInfo.getRoleName());
			roleInfoVo.setParentId(roleInfo.getParentId());
			voList.add(roleInfoVo);
			roleNameObj.put(roleInfo.getRoleId(), roleInfo.getRoleName());
		}
		modelMap.put("roleList", voList);
		modelMap.put("roleNameObj", roleNameObj);
		modelMap.put("roleId", 0);
    	return modelMap;
    }
	
	@RequestMapping("/getRoleTreeByOrg")
	public Map<String, Object> getRoleTreeByOrg(Integer orgId) {
		Map<String, Object> map = new HashMap<>();
		map.put("orgId", orgId);
		List<RoleInfo> list = roleInfoService.getRoleTreeByOrg(map);	
		Map<String, Object> modelMap = new HashMap<>();
		List<RoleInfoVo> voList = new ArrayList<RoleInfoVo>();
		Map<Integer, String> roleNameObj = new HashMap<Integer, String>();
		for (RoleInfo roleInfo : list) {
			RoleInfoVo roleInfoVo = new RoleInfoVo();
			roleInfoVo.setId(roleInfo.getRoleId());
			roleInfoVo.setName(roleInfo.getRoleName());
			roleInfoVo.setParentId(roleInfo.getParentId());
			voList.add(roleInfoVo);
			roleNameObj.put(roleInfo.getRoleId(), roleInfo.getRoleName());
		}
		modelMap.put("roleList", voList);
		modelMap.put("roleNameObj", roleNameObj);
		modelMap.put("roleId", 0);
		return modelMap;
	}

}
