package com.chinaitop.depot.system.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.system.feignService.BasicFeignService;
import com.chinaitop.depot.system.model.SystemLog;
import com.chinaitop.depot.system.model.SystemLogExample;
import com.chinaitop.depot.system.model.SystemLogThree;
import com.chinaitop.depot.system.model.SystemLogTwo;
import com.chinaitop.depot.system.service.UserOperationlogService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 系统日志控制类
 * @author hf
 *
 */
@RestController
@RequestMapping(value="/systemLog")
@Api(description = "系统日志控制类")
public class SystemLogController {

	@Resource
	private UserOperationlogService userOperationlogService;

	@Resource
	private BasicFeignService basicFeignService;

	/**
	 * 查找日志信息
	 * @param pageNum	页码
	 * @param pageSize	每页条数
	 * @return
	 */
	@RequestMapping(value="/getSystemLog", method = RequestMethod.GET)
	@ApiOperation(value="查询日志信息", notes = "查询日志信息列表，支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "username", value = "真实姓名", paramType = "query")
	})
	public PageInfo<SystemLog> getSystemLog(HttpServletRequest request, Integer pageNum, 
			Integer pageSize, String username) {

		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}

		SystemLogExample example = new SystemLogExample();
		SystemLogExample.Criteria criteria = example.createCriteria();
		if (null != username && !"".equals(username)) {
			criteria.andUserNameLike("%"+username+"%");
		}
		example.setOrderByClause("operation_time desc");

		List<SystemLog> list = userOperationlogService.findSystemLogCondition(example);
		if (null != list && list.size() > 0) {
			SystemLog log = null;
			String parameter = "";
			int parameter_length = 0;
			for (int i = 0; i < list.size(); i++) {
				log = list.get(i);
				parameter = log.getParameter();
				if (null != parameter && !"".equals(parameter)) {
					parameter_length = parameter.length();
					if (parameter_length > 50) {
						parameter = parameter.substring(0, 50)+"......";
						log.setParameter(parameter);
					}
				}
			}
		}

		PageInfo<SystemLog> pageInfo = new PageInfo<SystemLog>(list);

		return pageInfo;
	}

	@RequestMapping(value="/save", method = RequestMethod.POST)
	@ApiOperation(value="插入日志信息", notes = "插入日志信息")
	@ApiImplicitParams({})
	public Map<String, Object> save(HttpServletRequest request) {

		Map<String, Object> map = new HashMap<String, Object>();
		//获取用户信息和单位信息
        String userJson = ObjectUtils.toString(request.getSession().getAttribute("userInfo"),"");
        String orgInfoJson = ObjectUtils.toString(request.getSession().getAttribute("orgInfo"),"");

        if (!"".equals(userJson) && !"".equals(orgInfoJson)) {
        	JSONObject userinfo = JSONObject.parseObject(userJson);
        	JSONObject orginfo = JSONObject.parseObject(orgInfoJson);

        	SystemLogThree log = new SystemLogThree();
        	log.setId(UUID.randomUUID().toString().replace("-", ""));
        	log.setType("3");//功能访问日志
        	log.setSystemIdentify("库级系统");//标识
        	log.setUserId(Integer.parseInt(userinfo.get("userId").toString()));//用户ID
        	log.setUserZh(ObjectUtils.toString(userinfo.get("username").toString(),""));//账号
        	log.setUserName(ObjectUtils.toString(userinfo.get("realName"),""));//名称
        	String device_ip = getClientIpAddress(request);
        	log.setDeviceIp(device_ip);//操作IP
        	log.setFuncId(0);//功能ID
        	log.setFuncName("出入库");//功能名称
        	log.setOperationTime(new Date());//操作时间
        	log.setUserRole(ObjectUtils.toString(userinfo.get("roleNames"),""));//角色
        	log.setOrgId(Integer.parseInt(userinfo.get("orgId").toString()));//单位

        	String enumid = ObjectUtils.toString(orginfo.get("areaCode"), "0");
        	if (!"0".equals(enumid)) {
        		String strResult = basicFeignService.getEnumData(Integer.parseInt(enumid));
				if (null != strResult && !"".equals(strResult)) {
					JSONObject enum_obj = JSONObject.parseObject(strResult);
					log.setUserAddress(ObjectUtils.toString(enum_obj.get("gbcode"), ""));//行政区划
				}
        	}

        	//添加保存日志
        	userOperationlogService.AddSystemLog(log);
        }

		return map;
	}

	/**
     * 获取客户端IP
     * 
     * @param request
     * @return
     */
    private String getClientIpAddress(HttpServletRequest request) {  
        String clientIp = request.getHeader("x-forwarded-for");  
        if(clientIp == null || clientIp.length() == 0 || "unknown".equalsIgnoreCase(clientIp)) {  
            clientIp = request.getHeader("Proxy-Client-IP");  
        }  
        if(clientIp == null || clientIp.length() == 0 || "unknown".equalsIgnoreCase(clientIp)) {  
            clientIp = request.getHeader("WL-Proxy-Client-IP");  
        }  
        if(clientIp == null || clientIp.length() == 0 || "unknown".equalsIgnoreCase(clientIp)) {  
            clientIp = request.getRemoteAddr();  
        }  
        return "0:0:0:0:0:0:0:1".equals(clientIp) ? "127.0.0.1" : clientIp;  
    }

}
