package com.chinaitop.depot.system.service;

import com.chinaitop.depot.system.model.UserInfo;
import com.chinaitop.depot.system.model.UserInfoExample;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public interface UserInfoService {
	
	/**
	 * 验证用户名，密码是否正确
	 * @param username
	 * @param password
	 * @return
	 */
	UserInfo valid(String username, String password);

	/**
	 * 根据用户名，机构获取用户信息
	 * @param username
	 * @param orgId
	 * @return
	 */
	UserInfo validByProvince(String username, Integer orgId);
	
	/**
	 * 验证用户名是否可用
	 * @param userId
	 * @param username
	 * @return
	 */
	boolean validUsername(Integer userId, String username);
	
	/**
	 * 验证手机号是否可用
	 * @param phoneNumber
	 * @param userId
	 * @return
	 */
	String validPhone(String phoneNumber, Integer userId);
	
	/**
	 * 通过用户名查询手机号
	 * @param username
	 * @return
	 */
	String queryPhoneByusername(String username);

	/**
	 * 验证用户输入的原密码是否正确
	 * @param resPassword 数据库中保存的密码
	 * @param oldPassword	用户输入的原密码
	 * @return
	 */
	boolean validPassword(String resPassword, String oldPassword);

	/**
	 * 重置密码
	 * @param userId	用户编号
	 */
	void resetPassword(Integer userId,String userPwd);
	
	/**
	 * 根据条件查询用户列表
	 * @param example
	 * @return
	 */
	List<UserInfo> queryByExample(UserInfoExample example);
	
	/**
	 * 根据用户编号获取用户信息
	 * @param userId
	 * @return
	 */
	UserInfo findById(Integer userId);
	
	/**
	 * 新增用户
	 * @param userInfo
	 */
	void add(UserInfo userInfo);
	
	/**
	 * 更新用户信息
	 * @param userInfo
	 */
	void update(UserInfo userInfo);
	
	/**
	 * 根据用户编号删除用户信息
	 * @param userId
	 */
	void remove(Integer userId);

	//列表查询
	List<UserInfo> queryAll(HashMap<Object, Object> map);
	
	String getMD5(String str);
	
	/**
	 * 查询业务表
	 */
	List<String> queryUserBusiness();

	/**
	 * 查找审批用户信息
	 * @param map
	 * @return
	 */
	List<Map<Object, Object>> queryAuditUser(Map<Object, Object> map);
	
	/**
	 * 根据条件查询行政机构用户列表
	 * @param map
	 * @return
	 */
	List<UserInfo> queryAllByOrgClass(Map<Object, Object> map);

	List<UserInfo> getUserInfoByRole(Integer orgId);

	/**
	 * 删除当前用户数据和当前用户关联的部分数据
	 * 
	 * @param userId
	 * @throws Exception
	 */
	void deleteAll(Integer userId) throws Exception;
}
